boofun.analysis.sensitivity
===========================

.. automodule:: boofun.analysis.sensitivity


   .. rubric:: Functions

   .. autosummary::

      arg_max_sensitivity
      arg_min_sensitivity
      average_sensitivity
      average_sensitivity_moment
      max_sensitivity
      min_sensitivity
      sensitive_coordinates
      sensitivity_at
      sensitivity_histogram
      sensitivity_profile
      total_influence_via_sensitivity
